@@ -1,7 +1,7 @@
 # coding=utf-8
 from typing import cast, ClassVar, NewType
 
-__all__ = ['JobStatusString', 'StepName', 'ChallengesConstants']
+__all__ = ["JobStatusString", "StepName", "ChallengesConstants"]
 
 JobStatusString = NewType("JobStatusString", str)
 StepName = NewType("StepName", str)
@@ -10,13 +10,9 @@ StepName = NewType("StepName", str)
 class ChallengesConstants:
     # status for evaluation jobs
     STATUS_JOB_TIMEOUT: ClassVar[JobStatusString] = cast(JobStatusString, "timeout")
-    STATUS_JOB_EVALUATION: ClassVar[JobStatusString] = cast(
-        JobStatusString, "evaluating"
-    )
+    STATUS_JOB_EVALUATION: ClassVar[JobStatusString] = cast(JobStatusString, "evaluating")
     STATUS_JOB_FAILED: ClassVar[JobStatusString] = cast(JobStatusString, "failed")
-    STATUS_JOB_ERROR: ClassVar[JobStatusString] = cast(
-        JobStatusString, "error"
-    )  # evaluation failed
+    STATUS_JOB_ERROR: ClassVar[JobStatusString] = cast(JobStatusString, "error")  # evaluation failed
     STATUS_JOB_HOST_ERROR: ClassVar[JobStatusString] = cast(
         JobStatusString, "host-error"
     )  # evaluation failed
